@@ -84,7 +84,7 @@
 #define KAUTH_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTH_NO_DEPRECATED
-#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KAUTH_NO_DEPRECATED_WARNINGS
 #  define KAUTH_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTH_DEPRECATED_WARNINGS_SINCE KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
